@@ -23,7 +23,6 @@ from Bio import SeqIO
 from Bio.Align import MultipleSeqAlignment
 from Bio.Seq import Seq
 from io import StringIO
-from collections import Counter
 import argparse
 import dendropy
 from dendropy.calculate import treecompare
@@ -35,7 +34,11 @@ import subprocess
 import sys
 import tempfile
 import time
-from gubbins.Fastml import Fastml
+from gubbins.PreProcessFasta import PreProcessFasta
+from gubbins.ValidateFastaAlignment import ValidateFastaAlignment
+from gubbins.RAxMLSequenceReconstruction import RAxMLSequenceReconstruction
+from gubbins.RAxMLExecutable import RAxMLExecutable
+
 
 class GubbinsError(Exception):
   def __init__(self, value,message):
@@ -80,26 +83,6 @@ class GubbinsCommon():
     return 1
 
 
-  @staticmethod
-  def does_fasta_contain_variation(alignment_filename):
-    with open(alignment_filename, "r") as input_handle:
-      alignments = AlignIO.parse(input_handle, "fasta")
-      first_sequence = ""
-      
-      for index, alignment in enumerate(alignments):
-        for record_index, record in enumerate(alignment):
-      
-          if record_index == 0:
-            first_sequence = record.seq
-      
-          if str(record.seq) != str(first_sequence):
-            input_handle.close()
-            return 1
-            
-      input_handle.close()
-    return 0
-
-
   @staticmethod
   def does_file_exist(alignment_filename, file_type_msg):
     if(not os.path.exists(alignment_filename)):
@@ -110,17 +93,8 @@ class GubbinsCommon():
   @staticmethod
   def choose_executable(list_of_executables):
     flags = []
-    if os.path.exists('/proc/cpuinfo'):
-      output = subprocess.Popen('grep flags /proc/cpuinfo', stdout = subprocess.PIPE, shell=True).communicate()[0]
-      flags =  output.split()
     
     for executable in list_of_executables:
-      if os.path.exists('/proc/cpuinfo'):
-        if re.search('AVX', executable) and 'avx' not in flags:
-          continue
-        elif re.search('SSE3', executable) and 'ssse3'  not in flags:
-          continue
-      
       if GubbinsCommon.which(executable) != None:
         return executable
         
@@ -128,21 +102,7 @@ class GubbinsCommon():
 
   def parse_and_run(self):
     # Default parameters
-    raxml_executables = ['raxmlHPC-AVX','raxmlHPC-SSE3','raxmlHPC']
-    if self.args.threads > 1:
-      raxml_executables = ['raxmlHPC-PTHREADS-AVX','raxmlHPC-PTHREADS-SSE3','raxmlHPC-PTHREADS','raxmlHPC-AVX','raxmlHPC-SSE3','raxmlHPC']
-    raxml_executable = GubbinsCommon.choose_executable(raxml_executables)
-    
-    # raxml PTHREADS needs 2 or more threads, however some systems dont come with the single threaded exec
-    if self.args.threads == 1 and raxml_executable == "":
-      self.args.threads = 2
-      raxml_executables = ['raxmlHPC-PTHREADS-AVX','raxmlHPC-PTHREADS-SSE3','raxmlHPC-PTHREADS']
-      print("Trying PTHREADS version of raxml because no single threaded version of raxml could be found. Just to warn you, this requires 2 threads.\n")
-      raxml_executable = GubbinsCommon.choose_executable(raxml_executables)
-    
-    RAXML_EXEC = raxml_executable+' -f d -p 1 -m GTRGAMMA'
-    if re.search('PTHREADS', str(RAXML_EXEC)) != None:
-      RAXML_EXEC = RAXML_EXEC+" -T " +str(self.args.threads)
+    raxml_executable_obj = RAxMLExecutable(self.args.threads, self.args.verbose)
     
     fasttree_executables = ['FastTree','fasttree']
     FASTTREE_EXEC = GubbinsCommon.choose_executable(fasttree_executables)
@@ -150,8 +110,6 @@ class GubbinsCommon():
     FASTTREE_PARAMS = '-nosupport -gtr -gamma -nt'
     GUBBINS_EXEC = 'gubbins'
 
-    FASTML_EXEC = Fastml('fastml').fastml_parameters
-
     GUBBINS_BUNDLED_EXEC = '../src/gubbins'
 
     # check that all the external executable dependancies are available
@@ -159,10 +117,6 @@ class GubbinsCommon():
       GUBBINS_EXEC = GubbinsCommon.use_bundled_exec(GUBBINS_EXEC, GUBBINS_BUNDLED_EXEC)
       if GubbinsCommon.which(GUBBINS_EXEC) is None:
         sys.exit(GUBBINS_EXEC+" is not in your path")
-    if GubbinsCommon.which(FASTML_EXEC) is None:
-      sys.exit("fastml is not in your path")
-    if (self.args.tree_builder == "raxml" or self.args.tree_builder == "hybrid") and GubbinsCommon.which(RAXML_EXEC) is None:
-      sys.exit("RAxML is not in your path")
       
     if self.args.tree_builder == "fasttree" or self.args.tree_builder == "hybrid":
       if GubbinsCommon.which(FASTTREE_EXEC) is None:
@@ -171,7 +125,7 @@ class GubbinsCommon():
     if self.args.converge_method not in ['weighted_robinson_foulds','robinson_foulds','recombination']:
       sys.exit("Please choose weighted_robinson_foulds, robinson_foulds or recombination for the --converge_method option")
 
-    if(GubbinsCommon.does_file_exist(self.args.alignment_filename, 'Alignment File') == 0 or GubbinsCommon.is_input_fasta_file_valid(self.args.alignment_filename) == 0 ):
+    if(GubbinsCommon.does_file_exist(self.args.alignment_filename, 'Alignment File') == 0 or not ValidateFastaAlignment(self.args.alignment_filename).is_input_fasta_file_valid() ):
        sys.exit("There is a problem with your input fasta file so nothing can be done until you fix it")
        
     if(self.args.starting_tree is not None and self.args.starting_tree != "" and (GubbinsCommon.does_file_exist(self.args.starting_tree, 'Starting Tree') == 0 or GubbinsCommon.is_input_starting_tree_valid(self.args.starting_tree) )):
@@ -195,7 +149,10 @@ class GubbinsCommon():
 
     # put a filtered copy into a temp directory and work from that
     temp_working_dir = tempfile.mkdtemp(dir=os.getcwd())
-    taxa_removed = GubbinsCommon.filter_out_alignments_with_too_much_missing_data(self.args.alignment_filename, temp_working_dir+"/"+starting_base_filename, self.args.filter_percentage, self.args.verbose)
+    
+    pre_process_fasta = PreProcessFasta(self.args.alignment_filename,self.args.verbose,self.args.filter_percentage)
+    taxa_removed = pre_process_fasta.remove_duplicate_sequences_and_sequences_missing_too_much_data(temp_working_dir+"/"+starting_base_filename)
+    
     self.args.alignment_filename = temp_working_dir+"/"+starting_base_filename
 
     # If a starting tree has been provided make sure that taxa filtered out in the previous step are removed from the tree
@@ -222,11 +179,10 @@ class GubbinsCommon():
 
     GubbinsCommon.reconvert_fasta_file(starting_base_filename+".gaps.snp_sites.aln",starting_base_filename+".start")
 
-    # Perform pairwise comparison if there are only 2 sequences
+
     number_of_sequences = GubbinsCommon.number_of_sequences_in_alignment(self.args.alignment_filename)
-    if(number_of_sequences == 2):
-      GubbinsCommon.pairwise_comparison(self.args.alignment_filename,starting_base_filename,GUBBINS_EXEC,self.args.alignment_filename,FASTML_EXEC,base_filename_without_ext)
-      sys.exit()
+    if(number_of_sequences < 3):
+      sys.exit("4 or more sequences are required.")
 
     latest_file_name = "latest_tree."+base_filename_without_ext+"."+str(current_time)+"tre"
     tree_file_names = []
@@ -253,27 +209,24 @@ class GubbinsCommon():
           previous_tree_name    = GubbinsCommon.fasttree_previous_tree_name(base_filename, i)
           current_tree_name     = GubbinsCommon.fasttree_current_tree_name(base_filename, i)
           tree_building_command = GubbinsCommon.fasttree_tree_building_command(i, self.args.starting_tree,current_tree_name,base_filename,previous_tree_name,FASTTREE_EXEC, FASTTREE_PARAMS,base_filename )
-          fastml_command        = GubbinsCommon.fasttree_fastml_command(FASTML_EXEC, starting_base_filename+".snp_sites.aln", base_filename, i)
           gubbins_command       = GubbinsCommon.fasttree_gubbins_command(base_filename,starting_base_filename+".gaps", i,self.args.alignment_filename,GUBBINS_EXEC,self.args.min_snps,self.args.alignment_filename, self.args.min_window_size,self.args.max_window_size)
 
         elif i == 2:
           previous_tree_name    = current_tree_name
           current_tree_name     = GubbinsCommon.raxml_current_tree_name(base_filename_without_ext,current_time, i)
-          tree_building_command = GubbinsCommon.raxml_tree_building_command(i,base_filename_without_ext,base_filename,current_time,RAXML_EXEC,previous_tree_name, self.args.verbose)
-          fastml_command        = GubbinsCommon.raxml_fastml_command(FASTML_EXEC, starting_base_filename+".snp_sites.aln", base_filename_without_ext,current_time, i)
+          tree_building_command = GubbinsCommon.raxml_tree_building_command(i,base_filename_without_ext,base_filename,current_time,raxml_executable_obj.tree_building_command(),previous_tree_name, self.args.verbose)
           gubbins_command       = GubbinsCommon.raxml_gubbins_command(base_filename_without_ext,starting_base_filename+".gaps",current_time, i,self.args.alignment_filename,GUBBINS_EXEC,self.args.min_snps,self.args.alignment_filename, self.args.min_window_size,self.args.max_window_size)
         else:
           previous_tree_name    = GubbinsCommon.raxml_previous_tree_name(base_filename_without_ext,base_filename, current_time,i)
           current_tree_name     = GubbinsCommon.raxml_current_tree_name(base_filename_without_ext,current_time, i)
-          tree_building_command = GubbinsCommon.raxml_tree_building_command(i,base_filename_without_ext,base_filename,current_time,RAXML_EXEC,previous_tree_name, self.args.verbose)
-          fastml_command        = GubbinsCommon.raxml_fastml_command(FASTML_EXEC, starting_base_filename+".snp_sites.aln", base_filename_without_ext,current_time, i)
+          tree_building_command = GubbinsCommon.raxml_tree_building_command(i,base_filename_without_ext,base_filename,current_time,raxml_executable_obj.tree_building_command(),previous_tree_name, self.args.verbose)
           gubbins_command       = GubbinsCommon.raxml_gubbins_command(base_filename_without_ext,starting_base_filename+".gaps",current_time, i,self.args.alignment_filename,GUBBINS_EXEC,self.args.min_snps,self.args.alignment_filename, self.args.min_window_size,self.args.max_window_size)
 
       elif self.args.tree_builder == "raxml":
         previous_tree_name    = GubbinsCommon.raxml_previous_tree_name(base_filename_without_ext,base_filename, current_time,i)
         current_tree_name     = GubbinsCommon.raxml_current_tree_name(base_filename_without_ext,current_time, i)
-        tree_building_command = GubbinsCommon.raxml_tree_building_command(i,base_filename_without_ext,base_filename,current_time,RAXML_EXEC,previous_tree_name, self.args.verbose)
-        fastml_command        = GubbinsCommon.raxml_fastml_command(FASTML_EXEC, starting_base_filename+".snp_sites.aln", base_filename_without_ext,current_time, i)
+        tree_building_command = GubbinsCommon.raxml_tree_building_command(i,base_filename_without_ext,base_filename,current_time,raxml_executable_obj.tree_building_command(),previous_tree_name, self.args.verbose)
+		
         gubbins_command       = GubbinsCommon.raxml_gubbins_command(base_filename_without_ext,starting_base_filename+".gaps",current_time, i,self.args.alignment_filename,GUBBINS_EXEC,self.args.min_snps,self.args.alignment_filename, self.args.min_window_size,self.args.max_window_size)
 
       elif self.args.tree_builder == "fasttree":
@@ -283,7 +236,6 @@ class GubbinsCommon():
         current_tree_name     = GubbinsCommon.fasttree_current_tree_name(base_filename, i)
 
         tree_building_command = GubbinsCommon.fasttree_tree_building_command(i, self.args.starting_tree,current_tree_name,previous_tree_name,previous_tree_name,FASTTREE_EXEC,FASTTREE_PARAMS,base_filename )
-        fastml_command        = GubbinsCommon.fasttree_fastml_command(FASTML_EXEC, starting_base_filename+".snp_sites.aln", base_filename, i)
         gubbins_command       = GubbinsCommon.fasttree_gubbins_command(base_filename,starting_base_filename+".gaps", i,self.args.alignment_filename,GUBBINS_EXEC,self.args.min_snps,self.args.alignment_filename, self.args.min_window_size,self.args.max_window_size)
 
       if self.args.verbose > 0:
@@ -303,24 +255,18 @@ class GubbinsCommon():
 
       GubbinsCommon.reroot_tree(str(current_tree_name), self.args.outgroup)
 
-      fastml_command_suffix = ' > /dev/null 2>&1'
-      if self.args.verbose > 0:
-        print(fastml_command)
-        fastml_command_suffix = ''
+      try:  
+        raxml_seq_recon = RAxMLSequenceReconstruction(starting_base_filename+".snp_sites.aln", current_tree_name, starting_base_filename+".seq.joint.txt", current_tree_name , raxml_executable_obj.internal_sequence_reconstruction_command(), self.args.verbose)
+        raxml_seq_recon.reconstruct_ancestor_sequences()
 
-
-      try:
-        subprocess.check_call(fastml_command+fastml_command_suffix, shell=True)
       except:
-        sys.exit("Failed while running FastML")
+        sys.exit("Failed while running RAxML internal sequence reconstruction")
         
-      shutil.copyfile(current_tree_name+'.output_tree',current_tree_name)
       shutil.copyfile(starting_base_filename+".start", starting_base_filename+".gaps.snp_sites.aln")
-      GubbinsCommon.reinsert_gaps_into_fasta_file(current_tree_name+'.seq.joint.txt', starting_base_filename +".gaps.vcf", starting_base_filename+".gaps.snp_sites.aln")
-
-      if(GubbinsCommon.does_file_exist(starting_base_filename+".gaps.snp_sites.aln", 'Alignment File') == 0 or GubbinsCommon.is_input_fasta_file_valid(starting_base_filename+".gaps.snp_sites.aln") == 0 ):
-         sys.exit("There is a problem with your FASTA file after running FASTML. Please check this intermediate file is valid: "+ str(starting_base_filename)+".gaps.snp_sites.aln")
+      GubbinsCommon.reinsert_gaps_into_fasta_file(starting_base_filename+".seq.joint.txt", starting_base_filename +".gaps.vcf", starting_base_filename+".gaps.snp_sites.aln")
 
+      if(GubbinsCommon.does_file_exist(starting_base_filename+".gaps.snp_sites.aln", 'Alignment File') == 0 or not ValidateFastaAlignment(starting_base_filename+".gaps.snp_sites.aln").is_input_fasta_file_valid() ):
+         sys.exit("There is a problem with your FASTA file after running RAxML internal sequence reconstruction. Please check this intermediate file is valid: "+ str(starting_base_filename)+".gaps.snp_sites.aln")
 
       if self.args.verbose > 0:
         print(int(time.time()))
@@ -515,6 +461,7 @@ class GubbinsCommon():
     GubbinsCommon.split_all_non_bi_nodes(tree.seed_node)
 
     tree.update_bipartitions()
+    tree.reroot_at_midpoint()
     tree.deroot()
     tree.update_bipartitions()
     output_tree_string = tree.as_string(
@@ -645,21 +592,6 @@ class GubbinsCommon():
   def translation_of_raxml_filenames_to_final_filenames(base_filename_without_ext,current_time, max_intermediate_iteration, output_prefix):
     return GubbinsCommon.translation_of_filenames_to_final_filenames("RAxML_result."+GubbinsCommon.raxml_base_name(base_filename_without_ext,current_time)+str(max_intermediate_iteration), output_prefix)
 
-  @staticmethod
-  def translation_of_filenames_to_final_filenames_pairwise(input_prefix, output_prefix):
-    input_names_to_output_names = {  
-      str(input_prefix)+".vcf":             str(output_prefix)+".summary_of_snp_distribution.vcf"  ,
-      str(input_prefix)+".branch_snps.tab": str(output_prefix)+".branch_base_reconstruction.embl"  ,
-      str(input_prefix)+".tab":             str(output_prefix)+".recombination_predictions.embl"   ,
-      str(input_prefix)+".gff":             str(output_prefix)+".recombination_predictions.gff"    ,
-      str(input_prefix)+".stats":           str(output_prefix)+".per_branch_statistics.csv"        ,
-      str(input_prefix)+".snp_sites.aln":   str(output_prefix)+".filtered_polymorphic_sites.fasta" ,
-      str(input_prefix)+".phylip":          str(output_prefix)+".filtered_polymorphic_sites.phylip",
-      str(input_prefix)+".output_tree":     str(output_prefix)+".node_labelled.tre",
-      str(input_prefix)+".tre":             str(output_prefix)+".final_tree.tre"
-    }
-    return input_names_to_output_names
-
   @staticmethod
   def translation_of_filenames_to_final_filenames(input_prefix, output_prefix):
     input_names_to_output_names = {  
@@ -700,29 +632,6 @@ class GubbinsCommon():
     current_tree_name = GubbinsCommon.fasttree_current_tree_name(base_filename, i)
     return gubbins_exec+" -r -v "+starting_base_filename+".vcf"+" -a "+str(min_window_size)+" -b "+str(max_window_size) + " -f "+original_aln+" -t "+str(current_tree_name)+" -m "+ str(min_snps)+" "+ starting_base_filename+".snp_sites.aln"
 
-  @staticmethod
-  def fasttree_fastml_command(fastml_exec, alignment_filename, base_filename,i):
-    current_tree_name = GubbinsCommon.fasttree_current_tree_name(base_filename, i)
-    return GubbinsCommon.generate_fastml_command(fastml_exec, alignment_filename, current_tree_name)
-
-  @staticmethod
-  def raxml_fastml_command(fastml_exec, alignment_filename, base_filename_without_ext,current_time, i):
-    current_tree_name = GubbinsCommon.raxml_current_tree_name(base_filename_without_ext,current_time, i)
-    return GubbinsCommon.generate_fastml_command(fastml_exec, alignment_filename, current_tree_name)
-
-  @staticmethod
-  def generate_fastml_command(fastml_exec, alignment_filename, tree_filename):
-
-    return (fastml_exec 
-      + " -s " + alignment_filename 
-      + " -t " + tree_filename 
-      + " -x " + tree_filename + ".output_tree"
-      + " -y " + tree_filename + ".ancestor.tre"
-      + " -j " + tree_filename + ".seq.joint.txt"
-      + " -k " + tree_filename + ".seq.marginal.txt"
-      + " -d " + tree_filename + ".prob.joint.txt"
-      + " -e " + tree_filename + ".prob.marginal.txt")
-
   @staticmethod
   def number_of_sequences_in_alignment(filename):
     return len(GubbinsCommon.get_sequence_names_from_alignment(filename))
@@ -735,26 +644,6 @@ class GubbinsCommon():
         sequence_names.append(record.id)
       handle.close()
     return sequence_names
-
-  @staticmethod
-  def is_input_fasta_file_valid(input_filename):
-    try:
-      if GubbinsCommon.does_each_sequence_have_the_same_length(input_filename) == 0:
-        print("Each sequence must be the same length")
-        return 0
-      if GubbinsCommon.are_sequence_names_unique(input_filename) == 0:
-        print("All sequence names in the fasta file must be unique")
-        return 0
-      if GubbinsCommon.does_each_sequence_have_a_name_and_genomic_data(input_filename) == 0:
-        print("Each sequence must have a name and some genomic data")
-        return 0
-      if GubbinsCommon.does_fasta_contain_variation(input_filename) == 0:
-        print("All of the input sequences contain the same data")
-        return 0
-    except:
-      return 0
-
-    return 1
     
   @staticmethod
   def is_input_starting_tree_valid(starting_tree):
@@ -767,99 +656,6 @@ class GubbinsCommon():
       return 0
 
     return 1
-  
-
-  @staticmethod
-  def does_each_sequence_have_a_name_and_genomic_data(input_filename):
-    with  open(input_filename, "r") as input_handle:
-      alignments = AlignIO.parse(input_handle, "fasta")
-      number_of_sequences = 0
-      for alignment in alignments:
-          for record in alignment:
-              number_of_sequences +=1
-              if record.name is None or record.name == "":
-                print("Error with the input FASTA file: One of the sequence names is blank")
-                return 0
-              if record.seq is None or record.seq == "":
-                print("Error with the input FASTA file: One of the sequences is empty")
-                return 0
-              if re.search('[^ACGTNacgtn-]', str(record.seq))  != None:
-                print("Error with the input FASTA file: One of the sequences contains odd characters, only ACGTNacgtn- are permitted")
-                return 0
-      if number_of_sequences <= 3:
-        print("Error with input FASTA file: you need more than 3 sequences to build a meaningful tree")
-        return 0
-      input_handle.close()
-    return 1
-    
-    
-  @staticmethod
-  def does_each_sequence_have_the_same_length(input_filename):
-    try:
-      with open(input_filename) as input_handle:
-      
-        alignments = AlignIO.parse(input_handle, "fasta")
-        sequence_length = -1
-        for alignment in alignments:
-            for record in alignment:
-               if sequence_length == -1:
-                 sequence_length = len(record.seq)
-               elif sequence_length != len(record.seq):
-                 print("Error with the input FASTA file: The sequences dont have the same lengths this isnt an alignment: "+record.name)
-                 return 0
-        input_handle.close()
-    except:
-      print("Error with the input FASTA file: It is in the wrong format so check its an alignment")
-      return 0
-    return 1
-
-  @staticmethod
-  def are_sequence_names_unique(input_filename):
-    with open(input_filename) as input_handle:
-      alignments = AlignIO.parse(input_handle, "fasta")
-      sequence_names = []
-      for alignment in alignments:
-          for record in alignment:
-              sequence_names.append(record.name)
-              
-      if [k for k,v in list(Counter(sequence_names).items()) if v>1] != []:
-        return 0
-      input_handle.close()
-    return 1
-
-  @staticmethod
-  def filter_out_alignments_with_too_much_missing_data(input_filename, output_filename, filter_percentage,verbose):
-    with open(input_filename) as input_handle:
-      with open(output_filename, "w+") as output_handle:
-        alignments = AlignIO.parse(input_handle, "fasta")
-        output_alignments = []
-        taxa_removed = []
-        number_of_included_alignments = 0
-        for alignment in alignments:
-            for record in alignment:
-              number_of_gaps = 0
-              number_of_gaps += record.seq.count('n')
-              number_of_gaps += record.seq.count('N')
-              number_of_gaps += record.seq.count('-')
-              sequence_length = len(record.seq)
-        
-              if sequence_length == 0:
-                taxa_removed.append(record.id)
-                print("Excluded sequence " + record.id + " because there werent enough bases in it")
-              elif((number_of_gaps*100/sequence_length) <= filter_percentage):
-                output_alignments.append(record)
-                number_of_included_alignments += 1
-              else:
-                taxa_removed.append(record.id)
-                print("Excluded sequence " + record.id + " because it had " + str(number_of_gaps*100/sequence_length) +" percentage gaps while a maximum of "+ str(filter_percentage) +" is allowed")
-        
-        if number_of_included_alignments <= 1:
-          sys.exit("Too many sequences have been excluded so theres no data left to work with. Please increase the -f parameter")
-        
-        AlignIO.write(MultipleSeqAlignment(output_alignments), output_handle, "fasta")
-        output_handle.close()
-      input_handle.close()
-    return taxa_removed
 
   @staticmethod
   def filter_out_removed_taxa_from_tree_and_return_new_file(starting_tree, temp_working_dir, taxa_removed):
@@ -956,8 +752,6 @@ class GubbinsCommon():
         output_handle.close()
     return
 
-
-    # reparsing a fasta file splits the lines which makes fastml work
   @staticmethod
   def reconvert_fasta_file(input_filename, output_filename):
     with open(input_filename, "r") as input_handle:
@@ -968,29 +762,6 @@ class GubbinsCommon():
       input_handle.close()
     return
 
-  @staticmethod
-  def pairwise_comparison(filename,base_filename,gubbins_exec,alignment_filename,fastml_exec,base_filename_without_ext):
-    sequence_names = GubbinsCommon.get_sequence_names_from_alignment(filename)
-    GubbinsCommon.create_pairwise_newick_tree(sequence_names, base_filename+".tre")
-
-    try:
-      subprocess.check_call(GubbinsCommon.generate_fastml_command(fastml_exec, base_filename+".gaps.snp_sites.aln", base_filename+".tre"), shell=True)
-    except:
-      sys.exit("Failed while running fastML")
-    shutil.copyfile(base_filename+'.tre.output_tree',base_filename+".tre")
-    shutil.copyfile(base_filename+'.tre.seq.joint.txt', base_filename+".snp_sites.aln")
-    try:
-      subprocess.check_call(gubbins_exec+" -r -v "+base_filename+".vcf -t "+base_filename+".tre -f "+ alignment_filename +" "+ base_filename+".snp_sites.aln", shell=True)
-    except:
-      sys.exit("Failed while running Gubbins")
-    GubbinsCommon.rename_files(GubbinsCommon.translation_of_filenames_to_final_filenames_pairwise(base_filename, base_filename_without_ext))
-
-  @staticmethod
-  def create_pairwise_newick_tree(sequence_names, output_filename):
-    stringio = StringIO("".join(('(',sequence_names[0], ',', sequence_names[1],')')))
-    tree = Phylo.read(stringio, "newick")
-    Phylo.write(tree, output_filename, 'newick')
-
   @staticmethod
   def delete_files_based_on_list_of_regexes(directory_to_search, regex_for_file_deletions, verbose):
     for dirname, dirnames, filenames in os.walk(directory_to_search):
